<?

require_once("O3Spaces/BasePlugin.php");
require_once("O3Spaces/Utils.php");
require_once("O3Spaces/SOAP/WP_SOAP_Client.php");

class MailPlugin extends BasePlugin {

	/** Query the root webdav-paths for the e-mail folders 
	 * 
	 * @params $captureMetaProperties - Lookup WIS-namespace properties for each folder (expensive, HTTP OPTION and PROPFIND call per mail folder) 
	 * @returns array - containing keys "name", "webdav_path" for each found workspace 
	 */
	public function getMailRootFolders($captureMetaProperties = false) {

		$responseArray = $this->queryMailFolderWebDAVPaths();

		$folders = array();
		foreach ($responseArray as $folder) {
			list($workspace) = split("/", $folder, 2);
			$folder = array(
				"name" => urldecode($workspace), // in 2.4.1p1 not encoded but may in future
				"webdav_path" => Utils::escapeDirectoryParts($folder),
				"type" => "dir",
				"props" => array()
			);

			if ($captureMetaProperties) {
				$urlPath = Utils::urlAppendPath($this->cfg->getWebDAVLocation(), $folder["webdav_path"]);
				if ($dh = opendir($urlPath)) {
					$streamObject = stream_get_meta_data($dh);
					$streamObject = $streamObject["wrapper_data"];
					$folder["props"] = $streamObject->getDirProps();
//					$folder["props"]["O3:id"] = $streamObject->getDirProp("O3:id");
					closedir($dh);
				}
			}

			$folders[] = $folder;

		}

		return $folders;
	}

	/** Query the workplace for mail-service webdav paths */
	private function queryMailFolderWebDAVPaths() {

		$wsdl = Utils::urlAppendPath($this->cfg->getHTTPLocation(), "/osgi/axis/services/MailFolderService?wsdl");

		$soap = new WP_SOAP_Client( $wsdl, array(
			'features' => SOAP_SINGLE_ELEMENT_ARRAYS,
		) );

		$responseArray = $soap->getWebdavMailFolderPaths();
		return $responseArray;

	}



}

?>
